Class: Class

Inherits:
Object show all
Defined in:
lib/perennial/core_ext/attribute_accessors.rb,
lib/perennial/core_ext/misc.rb

Overview

cattr_* and class_inheritable_* are taken from ActiveSupport. Included here to help keep the codebase simple / clean.

Instance Method Summary collapse

Instance Method Details

#cattr_accessor(*syms) ⇒ Object



45
46
47
48
# File 'lib/perennial/core_ext/attribute_accessors.rb', line 45

def cattr_accessor(*syms)
  cattr_reader(*syms)
  cattr_writer(*syms)
end

#cattr_reader(*syms) ⇒ Object



5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
# File 'lib/perennial/core_ext/attribute_accessors.rb', line 5

def cattr_reader(*syms)
  syms.flatten.each do |sym|
    next if sym.is_a?(Hash)
    class_eval(<<-EOS, __FILE__, __LINE__ + 1)
      unless defined? @@#{sym}  # unless defined? @@hair_colors
        @@#{sym} = nil          #   @@hair_colors = nil
      end                       # end
                                #
      def self.#{sym}           # def self.hair_colors
        @@#{sym}                #   @@hair_colors
      end                       # end
                                #
      def #{sym}                # def hair_colors
        @@#{sym}                #   @@hair_colors
      end                       # end
    EOS
  end
end

#cattr_writer(*syms) ⇒ Object



24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
# File 'lib/perennial/core_ext/attribute_accessors.rb', line 24

def cattr_writer(*syms)
  options = syms.extract_options!
  syms.flatten.each do |sym|
    class_eval(<<-EOS, __FILE__, __LINE__ + 1)
      unless defined? @@#{sym}                       # unless defined? @@hair_colors
        @@#{sym} = nil                               #   @@hair_colors = nil
      end                                            # end
                                                     #
      def self.#{sym}=(obj)                          # def self.hair_colors=(obj)
        @@#{sym} = obj                               #   @@hair_colors = obj
      end                                            # end
                                                     #
      #{"                                            #
      def #{sym}=(obj)                               # def hair_colors=(obj)
        @@#{sym} = obj                               #   @@hair_colors = obj
      end                                            # end
      " unless options[:instance_writer] == false }  # # instance writer above is generated unless options[:instance_writer] == false
    EOS
  end
end

#class_inheritable_accessor(*syms, &block) ⇒ Array[#to_s]

Defines class-level inheritable attribute accessor. Attributes are available to subclasses, each subclass has a copy of parent's attribute.

Parameters:

  • *syms (Array[*#to_s, Hash{:instance_writer => Boolean}])

    Array of attributes to define inheritable accessor for.

  • syms (Hash)

    a customizable set of options

Options Hash (*syms):

  • :instance_writer (Boolean)

    if true, instance-level inheritable attribute writer is defined.

Returns:

  • (Array[#to_s])

    An Array of attributes turned into inheritable accessors.



124
125
126
127
# File 'lib/perennial/core_ext/attribute_accessors.rb', line 124

def class_inheritable_accessor(*syms, &block)
  class_inheritable_reader(*syms)
  class_inheritable_writer(*syms, &block)
end

#class_inheritable_reader(*ivars) ⇒ Array[#to_s]

TODO:

Do we want to block instance_reader via :instance_reader => false

TODO:

It would be preferable that we do something with a Hash passed in (error out or do the same as other methods above) instead of silently moving on). In particular, this makes the return value of this function less useful.

Defines class-level inheritable attribute reader. Attributes are available to subclasses, each subclass has a copy of parent's attribute.

Parameters:

  • *syms (Array[#to_s])

    Array of attributes to define inheritable reader for.

Returns:

  • (Array[#to_s])

    Array of attributes converted into inheritable_readers.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/perennial/core_ext/attribute_accessors.rb', line 63

def class_inheritable_reader(*ivars)
  instance_reader = ivars.pop[:reader] if ivars.last.is_a?(Hash)
 
  ivars.each do |ivar|
    self.class_eval <<-RUBY, __FILE__, __LINE__ + 1
      def self.#{ivar}
        return @#{ivar} if self.object_id == #{self.object_id} || defined?(@#{ivar})
        ivar = superclass.#{ivar}
        return nil if ivar.nil? && !#{self}.instance_variable_defined?("@#{ivar}")
        @#{ivar} = ivar && !ivar.is_a?(Module) && !ivar.is_a?(Numeric) && !ivar.is_a?(TrueClass) && !ivar.is_a?(FalseClass) ? ivar.dup : ivar
      end
    RUBY
    unless instance_reader == false
      self.class_eval <<-RUBY, __FILE__, __LINE__ + 1
        def #{ivar}
          self.class.#{ivar}
        end
      RUBY
    end
  end
end

#class_inheritable_writer(*ivars) ⇒ Array[#to_s]

TODO:

We need a style for class_eval <<-HEREDOC. I'd like to make it class_eval(<<-RUBY, FILE, LINE), but we should codify it somewhere.

Defines class-level inheritable attribute writer. Attributes are available to subclasses, each subclass has a copy of parent's attribute.

Parameters:

  • *syms (Array[*#to_s, Hash{:instance_writer => Boolean}])

    Array of attributes to define inheritable writer for.

  • syms (Hash)

    a customizable set of options

Returns:

  • (Array[#to_s])

    An Array of the attributes that were made into inheritable writers.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/perennial/core_ext/attribute_accessors.rb', line 97

def class_inheritable_writer(*ivars)
  instance_writer = ivars.pop[:writer] if ivars.last.is_a?(Hash)
  ivars.each do |ivar|
    self.class_eval <<-RUBY, __FILE__, __LINE__ + 1
      def self.#{ivar}=(obj)
        @#{ivar} = obj
      end
    RUBY
    unless instance_writer == false
      self.class_eval <<-RUBY, __FILE__, __LINE__ + 1
        def #{ivar}=(obj) self.class.#{ivar} = obj end
      RUBY
    end
 
    self.send("#{ivar}=", yield) if block_given?
  end
end

#is(*mixins) ⇒ Object



97
98
99
100
101
102
103
104
105
106
# File 'lib/perennial/core_ext/misc.rb', line 97

def is(*mixins)
  ns = Perennial::Manifest.namespace
  return if ns.blank?
  mixins.each do |mixin|
    real_name = mixin.to_s.camelize
    if ns.const_defined?(real_name)
      include ns.const_get(real_name)
    end
  end
end